==> cloudpos-common-classes-1.7-20210927.134852-359.jar: com/floreantpos/model/UserType.java <==
/**
 * ************************************************************************
 * * The contents of this file are subject to the MRPL 1.2
 * * (the  "License"),  being   the  Mozilla   Public  License
 * * Version 1.1  with a permitted attribution clause; you may not  use this
 * * file except in compliance with the License. You  may  obtain  a copy of
 * * the License at http://www.floreantpos.org/license.html
 * * Software distributed under the License  is  distributed  on  an "AS IS"
 * * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * * License for the specific  language  governing  rights  and  limitations
 * * under the License.
 * * The Original Code is FLOREANT POS.
 * * The Initial Developer of the Original Code is OROCUBE LLC
 * * All portions are Copyright (C) 2015 OROCUBE LLC
 * * All Rights Reserved.
 * ************************************************************************
 */
package com.floreantpos.model;

import java.util.Set;

import javax.xml.bind.annotation.XmlRootElement;

import com.floreantpos.model.base.BaseUserType;

@XmlRootElement(name = "user-type")
public class UserType extends BaseUserType implements TimedModel {
	private static final long serialVersionUID = 1L;

	private boolean updateLastUpdateTime = true;
	private boolean updateSyncTime = false;

	public boolean isUpdateSyncTime() {
		return updateSyncTime;
	}

	public void setUpdateSyncTime(boolean shouldUpdateSyncTime) {
		this.updateSyncTime = shouldUpdateSyncTime;
	}

	public boolean isUpdateLastUpdateTime() {
		return updateLastUpdateTime;
	}

	public void setUpdateLastUpdateTime(boolean shouldUpdateUpdateTime) {
		this.updateLastUpdateTime = shouldUpdateUpdateTime;
	}

	/*[CONSTRUCTOR MARKER BEGIN]*/
	public UserType() {
	}

	/**
	 * Constructor for primary key
	 */
	public UserType(java.lang.String id) {
		super(id);
	}

	/*[CONSTRUCTOR MARKER END]*/

	public void clearPermissions() {
		Set<UserPermission> permissions = getPermissions();
		if (permissions != null) {
			permissions.clear();
		}
	}

	public boolean hasPermission(UserPermission permission) {
		Set<UserPermission> permissions = getPermissions();
		if (permissions == null) {
			return false;
		}

		return permissions.contains(permission);
	}

	public String getPermissionsDisplay() {

		String permissions = getPermissions().toString();
		return permissions.substring(1, permissions.length() - 1);

	}

	@Override
	public String toString() {
		String s = getName();
		/*if(getPermissions() != null) {
			s += " " + getPermissions();
		}*/
		return s;
	}
}

==> cloudpos-common-classes-1.7-20210928.095647-362.jar: com/floreantpos/model/UserType.java <==
/**
 * ************************************************************************
 * * The contents of this file are subject to the MRPL 1.2
 * * (the  "License"),  being   the  Mozilla   Public  License
 * * Version 1.1  with a permitted attribution clause; you may not  use this
 * * file except in compliance with the License. You  may  obtain  a copy of
 * * the License at http://www.floreantpos.org/license.html
 * * Software distributed under the License  is  distributed  on  an "AS IS"
 * * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * * License for the specific  language  governing  rights  and  limitations
 * * under the License.
 * * The Original Code is FLOREANT POS.
 * * The Initial Developer of the Original Code is OROCUBE LLC
 * * All portions are Copyright (C) 2015 OROCUBE LLC
 * * All Rights Reserved.
 * ************************************************************************
 */
package com.floreantpos.model;

import java.util.Set;

import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlTransient;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.floreantpos.model.base.BaseUserType;

@JsonIgnoreProperties(ignoreUnknown = true, value = { "permissionsDisplay" })
@XmlRootElement(name = "user-type")
public class UserType extends BaseUserType implements TimedModel {
	private static final long serialVersionUID = 1L;

	private boolean updateLastUpdateTime = true;
	private boolean updateSyncTime = false;

	public boolean isUpdateSyncTime() {
		return updateSyncTime;
	}

	public void setUpdateSyncTime(boolean shouldUpdateSyncTime) {
		this.updateSyncTime = shouldUpdateSyncTime;
	}

	public boolean isUpdateLastUpdateTime() {
		return updateLastUpdateTime;
	}

	public void setUpdateLastUpdateTime(boolean shouldUpdateUpdateTime) {
		this.updateLastUpdateTime = shouldUpdateUpdateTime;
	}

	/*[CONSTRUCTOR MARKER BEGIN]*/
	public UserType() {
	}

	/**
	 * Constructor for primary key
	 */
	public UserType(java.lang.String id) {
		super(id);
	}

	/*[CONSTRUCTOR MARKER END]*/

	public void clearPermissions() {
		Set<UserPermission> permissions = getPermissions();
		if (permissions != null) {
			permissions.clear();
		}
	}

	public boolean hasPermission(UserPermission permission) {
		Set<UserPermission> permissions = getPermissions();
		if (permissions == null) {
			return false;
		}

		return permissions.contains(permission);
	}

	@XmlTransient
	@JsonIgnore
	public String getPermissionsDisplay() {

		String permissions = getPermissions().toString();
		return permissions.substring(1, permissions.length() - 1);

	}

	@Override
	public String toString() {
		String s = getName();
		/*if(getPermissions() != null) {
			s += " " + getPermissions();
		}*/
		return s;
	}
}
